@@ -49,19 +49,22 @@ def ensure_socket_response(func):
                 return value
             elif (args[0] in ['connect', 'disconnect', 'connect_error']):
                 return value
+            elif value is None:
+                return None
             else:
-                raise Exception(f"Returntype for sio must be str or bool or SocketResponse', but was {type(value)}'")
-        except Exception:
-            error = traceback.print_exc()
+                raise Exception(
+                    f"Return type for sio must be str, bool, SocketResponse or None', but was {type(value)}'"
+                )
+        except Exception as e:
             trace = ''.join(traceback.format_stack())
             logging.error(
                 f'\nAn error occured for {args[0]}:  \
                 \nStacktrace: \
                 \n{trace} \
                 \nError: \
-                \n {str(error)} \n'
+                \n {str(e)} \n'
             )
 
-            return SocketResponse.for_failure(str(error)).__dict__
+            return SocketResponse.for_failure(str(e)).__dict__
 
     return wrapper_ensure_socket_response
